from classes.Hello import HelloAgain

def start(name):
    return HelloAgain(name)


